@@ -1,48 +1,55 @@
 import copy
 import logging
-from typing import Any, Dict
+from typing import Dict, List
 
 from pytest_zebrunner.context import zebrunner_context
+from pytest_zebrunner.reporting_service import ReportingService
 
 logger = logging.getLogger(__name__)
 
 
 class SeleniumSession:
-    def __init__(self, reporting_service) -> None:  # type: ignore
-        self._active_sessions: Dict[str, Any] = {}
-        self.reporting_service = reporting_service
+    zebrunner_id: str
+    id: str
+    tests: List[int]
+
+    def __init__(self, id: str) -> None:
+        self.id = id
+        self.tests = []
+
+
+class SeleniumSessionManager:
+    def __init__(self, reporting_service: ReportingService) -> None:
+        self._active_sessions: Dict[str, SeleniumSession] = {}
+        self._reporting_service = reporting_service
 
     def start_session(self, session_id: str, capabilities: dict, desired_capabilities: dict) -> None:
-        self._active_sessions[session_id] = {"related_tests": []}
+        session = SeleniumSession(session_id)
+        self._active_sessions[session_id] = session
         if zebrunner_context.test_is_active:
-            self._active_sessions[session_id]["related_tests"].append(zebrunner_context.test_id)
+            session.tests.append(zebrunner_context.test_id)
 
-        zebrunner_session_id = self.reporting_service.start_test_session(
-            session_id, capabilities, desired_capabilities, self._active_sessions[session_id]["related_tests"]
+        zebrunner_session_id = self._reporting_service.start_test_session(
+            session_id, capabilities, desired_capabilities, self._active_sessions[session_id].tests
         )
         if zebrunner_session_id:
-            self._active_sessions[session_id]["zebrunner_session_id"] = zebrunner_session_id
+            session.zebrunner_id = zebrunner_session_id
 
     def finish_session(self, session_id: str) -> None:
-        self.reporting_service.finish_test_session(
-            self._active_sessions[session_id]["zebrunner_session_id"],
-            self._active_sessions[session_id]["related_tests"],
-        )
+        session = self._active_sessions[session_id]
+        self._reporting_service.finish_test_session(session.zebrunner_id, session.tests)
         del self._active_sessions[session_id]
 
     def finish_all_sessions(self) -> None:
-        for session_id in list(self._active_sessions):
+        for session_id in list(self._active_sessions.keys()):
             self.finish_session(session_id)
 
     def add_test(self, test_id: int) -> None:
-        for session_id in self._active_sessions:
-            if self._active_sessions[session_id].get("related_tests") is not None:
-                self._active_sessions[session_id]["related_tests"].append(test_id)
-            else:
-                self._active_sessions[session_id]["related_tests"] = [test_id]
+        for session in self._active_sessions.values():
+            session.tests.append(test_id)
 
 
-def inject_driver(session_manager: SeleniumSession) -> None:
+def inject_driver(session_manager: SeleniumSessionManager) -> None:
     try:
         from selenium.webdriver.remote.webdriver import WebDriver
 
